@@ -19,6 +19,7 @@ from django import forms
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
+from sentry import tagstore
 from sentry.exceptions import PluginError
 from sentry.plugins.bases import notify
 from sentry.http import is_valid_url, safe_urlopen
@@ -26,7 +27,7 @@ from sentry.utils.safe import safe_execute
 
 from sentry.utils.http import absolute_uri
 from django.core.urlresolvers import reverse
-from django.conf import settings
+
 
 # for dingtalk signature
 import hmac
@@ -82,17 +83,6 @@ class DingtalkPlugin(notify.NotificationPlugin):
     def is_configured(self, project, **kwargs):
         return bool(self.get_option('webhook', project))
 
-    # def get_config(self, project, **kwargs):
-    #     return [{
-    #         'name': 'urls',
-    #         'label': 'dingtalk robot url',
-    #         'type': 'textarea',
-    #         'help': 'Enter dingtalk robot url.',
-    #         'placeholder': 'https://oapi.dingtalk.com/robot/send?access_token=abcdefg',
-    #         'validators': [validate_urls],
-    #         'required': False
-    #     }] 
-
     def get_config(self, project, **kwargs):
         return [
             {
@@ -157,6 +147,7 @@ class DingtalkPlugin(notify.NotificationPlugin):
                 ),
             },
         ]
+
     def set_default(self, project, option, env_var):
         if self.get_option(option, project) != None:
             return self.get_option(option, project)
@@ -187,16 +178,6 @@ class DingtalkPlugin(notify.NotificationPlugin):
             verify_ssl=False,
         )
 
-    def get_group_url(self, group):
-        '''
-        return absolute_uri(reverse('sentry-group', args=[
-            group.organization.slug,
-            group.project.slug,
-            group.id,
-        ]))
-        '''
-        return absolute_uri(group.get_absolute_url())
-
     def notify_users(self, group, event, *args, **kwargs): 
         event = notification.event
         group = event.group
@@ -285,7 +266,7 @@ class DingtalkPlugin(notify.NotificationPlugin):
                     "text": payload
                     },
                 "at": {
-                    "atMobiles": ["150XXXXXXXX"],
+                    "atMobiles": [],
                     "isAtAll": false
                     }
                 }
